# This file was created automatically by SWIG.
import oglshapes2c

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *

from oglbasic import *

from oglshapes import *
import wx
class wxPyEllipseShapePtr(wxPyShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyEllipseShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyEllipseShape instance at %s>" % (self.this,)
class wxPyEllipseShape(wxPyEllipseShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapes2c.new_wxPyEllipseShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyEllipseShape)
        self._setOORInfo(self)




class wxPyCircleShapePtr(wxPyEllipseShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyCircleShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyCircleShape instance at %s>" % (self.this,)
class wxPyCircleShape(wxPyCircleShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapes2c.new_wxPyCircleShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyCircleShape)
        self._setOORInfo(self)




class wxArrowHeadPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=oglshapes2c.delete_wxArrowHead):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def _GetType(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead__GetType,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetPosition,(self,) + _args, _kwargs)
        return val
    def SetPosition(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_SetPosition,(self,) + _args, _kwargs)
        return val
    def GetXOffset(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetXOffset,(self,) + _args, _kwargs)
        return val
    def GetYOffset(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetYOffset,(self,) + _args, _kwargs)
        return val
    def GetSpacing(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetSpacing,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetSize,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetName,(self,) + _args, _kwargs)
        return val
    def SetXOffset(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_SetXOffset,(self,) + _args, _kwargs)
        return val
    def SetYOffset(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_SetYOffset,(self,) + _args, _kwargs)
        return val
    def GetMetaFile(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetMetaFile,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetId,(self,) + _args, _kwargs)
        return val
    def GetArrowEnd(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetArrowEnd,(self,) + _args, _kwargs)
        return val
    def GetArrowSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_GetArrowSize,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_SetSize,(self,) + _args, _kwargs)
        return val
    def SetSpacing(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxArrowHead_SetSpacing,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxArrowHead instance at %s>" % (self.this,)
class wxArrowHead(wxArrowHeadPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapes2c.new_wxArrowHead,_args,_kwargs)
        self.thisown = 1




class wxPyLineShapePtr(wxPyShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def AddArrow(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_AddArrow,(self,) + _args, _kwargs)
        return val
    def AddArrowOrdered(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_AddArrowOrdered,(self,) + _args, _kwargs)
        return val
    def ClearArrow(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_ClearArrow,(self,) + _args, _kwargs)
        return val
    def ClearArrowsAtPosition(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_ClearArrowsAtPosition,(self,) + _args, _kwargs)
        return val
    def DrawArrow(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_DrawArrow,(self,) + _args, _kwargs)
        return val
    def DeleteArrowHeadId(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_DeleteArrowHeadId,(self,) + _args, _kwargs)
        return val
    def DeleteArrowHead(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_DeleteArrowHead,(self,) + _args, _kwargs)
        return val
    def DeleteLineControlPoint(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_DeleteLineControlPoint,(self,) + _args, _kwargs)
        return val
    def DrawArrows(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_DrawArrows,(self,) + _args, _kwargs)
        return val
    def DrawRegion(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_DrawRegion,(self,) + _args, _kwargs)
        return val
    def EraseRegion(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_EraseRegion,(self,) + _args, _kwargs)
        return val
    def FindArrowHeadId(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_FindArrowHeadId,(self,) + _args, _kwargs)
        return val
    def FindArrowHead(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_FindArrowHead,(self,) + _args, _kwargs)
        return val
    def FindLineEndPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_FindLineEndPoints,(self,) + _args, _kwargs)
        return val
    def FindLinePosition(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_FindLinePosition,(self,) + _args, _kwargs)
        return val
    def FindMinimumWidth(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_FindMinimumWidth,(self,) + _args, _kwargs)
        return val
    def FindNth(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_FindNth,(self,) + _args, _kwargs)
        return val
    def GetAttachmentFrom(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetAttachmentFrom,(self,) + _args, _kwargs)
        return val
    def GetAttachmentTo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetAttachmentTo,(self,) + _args, _kwargs)
        return val
    def GetEnds(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetEnds,(self,) + _args, _kwargs)
        return val
    def GetFrom(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetFrom,(self,) + _args, _kwargs)
        return val
    def GetLabelPosition(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetLabelPosition,(self,) + _args, _kwargs)
        return val
    def GetNextControlPoint(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetNextControlPoint,(self,) + _args, _kwargs)
        if val: val = wxRealPointPtr(val) 
        return val
    def GetTo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetTo,(self,) + _args, _kwargs)
        return val
    def Initialise(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_Initialise,(self,) + _args, _kwargs)
        return val
    def InsertLineControlPoint(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_InsertLineControlPoint,(self,) + _args, _kwargs)
        return val
    def IsEnd(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_IsEnd,(self,) + _args, _kwargs)
        return val
    def IsSpline(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_IsSpline,(self,) + _args, _kwargs)
        return val
    def MakeLineControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_MakeLineControlPoints,(self,) + _args, _kwargs)
        return val
    def GetLineControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_GetLineControlPoints,(self,) + _args, _kwargs)
        return val
    def SetAttachmentFrom(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetAttachmentFrom,(self,) + _args, _kwargs)
        return val
    def SetAttachments(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetAttachments,(self,) + _args, _kwargs)
        return val
    def SetAttachmentTo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetAttachmentTo,(self,) + _args, _kwargs)
        return val
    def SetEnds(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetEnds,(self,) + _args, _kwargs)
        return val
    def SetFrom(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetFrom,(self,) + _args, _kwargs)
        return val
    def SetIgnoreOffsets(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetIgnoreOffsets,(self,) + _args, _kwargs)
        return val
    def SetSpline(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetSpline,(self,) + _args, _kwargs)
        return val
    def SetTo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_SetTo,(self,) + _args, _kwargs)
        return val
    def Straighten(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_Straighten,(self,) + _args, _kwargs)
        return val
    def Unlink(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_Unlink,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyLineShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyLineShape instance at %s>" % (self.this,)
class wxPyLineShape(wxPyLineShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapes2c.new_wxPyLineShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyLineShape)
        self._setOORInfo(self)




class wxPyPolygonShapePtr(wxPyShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def Create(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_Create,(self,) + _args, _kwargs)
        return val
    def AddPolygonPoint(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_AddPolygonPoint,(self,) + _args, _kwargs)
        return val
    def CalculatePolygonCentre(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_CalculatePolygonCentre,(self,) + _args, _kwargs)
        return val
    def DeletePolygonPoint(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_DeletePolygonPoint,(self,) + _args, _kwargs)
        return val
    def GetPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_GetPoints,(self,) + _args, _kwargs)
        return val
    def UpdateOriginalPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_UpdateOriginalPoints,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyPolygonShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyPolygonShape instance at %s>" % (self.this,)
class wxPyPolygonShape(wxPyPolygonShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapes2c.new_wxPyPolygonShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyPolygonShape)
        self._setOORInfo(self)




class wxPyTextShapePtr(wxPyRectangleShapePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglshapes2c.wxPyTextShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyTextShape instance at %s>" % (self.this,)
class wxPyTextShape(wxPyTextShapePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglshapes2c.new_wxPyTextShape,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyTextShape)
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------




#----------------------------------------------------------------------
# Name:        wxPython.lib.dialogs
# Purpose:     wxScrolledMessageDialog, wxMultipleChoiceDialog and
#              function wrappers for the common dialogs by Kevin Altis.
#
# Author:      Various
#
# Created:     3-January-2002
# RCS-ID:      $Id: dialogs.py,v 1.4.2.1 2003/01/04 07:10:19 RD Exp $
# Copyright:   (c) 2002 by Total Control Software
# Licence:     wxWindows license
#----------------------------------------------------------------------

from wxPython import wx
from layoutf import Layoutf

#----------------------------------------------------------------------

class wxScrolledMessageDialog(wx.wxDialog):
    def __init__(self, parent, msg, caption, pos = wx.wxDefaultPosition, size = (500,300)):
        wx.wxDialog.__init__(self, parent, -1, caption, pos, size)
        x, y = pos
        if x == -1 and y == -1:
            self.CenterOnScreen(wx.wxBOTH)
        text = wx.wxTextCtrl(self, -1, msg, wx.wxDefaultPosition,
                             wx.wxDefaultSize,
                             wx.wxTE_MULTILINE | wx.wxTE_READONLY)
        ok = wx.wxButton(self, wx.wxID_OK, "OK")
        text.SetConstraints(Layoutf('t=t5#1;b=t5#2;l=l5#1;r=r5#1', (self,ok)))
        ok.SetConstraints(Layoutf('b=b5#1;x%w50#1;w!80;h!25', (self,)))
        self.SetAutoLayout(1)
        self.Layout()


class wxMultipleChoiceDialog(wx.wxDialog):
    def __init__(self, parent, msg, title, lst, pos = wx.wxDefaultPosition, size = (200,200)):
        wx.wxDialog.__init__(self, parent, -1, title, pos, size)
        x, y = pos
        if x == -1 and y == -1:
            self.CenterOnScreen(wx.wxBOTH)
        dc = wx.wxClientDC(self)
        height = 0
        for line in msg.splitlines():
            height = height + dc.GetTextExtent(msg)[1] + 4
        stat = wx.wxStaticText(self, -1, msg)
        self.lbox = wx.wxListBox(self, 100, wx.wxDefaultPosition,
                                 wx.wxDefaultSize, lst, wx.wxLB_MULTIPLE)
        ok = wx.wxButton(self, wx.wxID_OK, "OK")
        cancel = wx.wxButton(self, wx.wxID_CANCEL, "Cancel")
        stat.SetConstraints(Layoutf('t=t10#1;l=l5#1;r=r5#1;h!%d' % (height,),
                                   (self,)))
        self.lbox.SetConstraints(Layoutf('t=b10#2;l=l5#1;r=r5#1;b=t5#3',
                                 (self, stat, ok)))
        ok.SetConstraints(Layoutf('b=b5#1;x%w25#1;w!80;h!25', (self,)))
        cancel.SetConstraints(Layoutf('b=b5#1;x%w75#1;w!80;h!25', (self,)))
        self.SetAutoLayout(1)
        self.lst = lst
        self.Layout()

    def GetValue(self):
        return self.lbox.GetSelections()

    def GetValueString(self):
        sel = self.lbox.GetSelections()
        val = []
        for i in sel:
            val.append(self.lst[i])
        return tuple(val)



#----------------------------------------------------------------------
"""
function wrappers for wxPython system dialogs
Author: Kevin Altis
Date:   2003-1-2
Rev:    3

This is the third refactor of the PythonCard dialog.py module
for inclusion in the main wxPython distribution. There are a number of
design decisions and subsequent code refactoring to be done, so I'm
releasing this just to get some feedback.

rev 3:
- result dictionary replaced by DialogResults class instance
- should message arg be replaced with msg? most wxWindows dialogs
  seem to use the abbreviation?

rev 2:
- All dialog classes have been replaced by function wrappers
- Changed arg lists to more closely match wxWindows docs and wxPython.lib.dialogs
- changed 'returned' value to the actual button id the user clicked on
- added a returnedString value for the string version of the return value
- reworked colorDialog and fontDialog so you can pass in just a color or font
    for the most common usage case
- probably need to use colour instead of color to match the English English
    spelling in wxWindows (sigh)
- I still think we could lose the parent arg and just always use None
"""

class DialogResults:
    def __init__(self, returned):
        self.returned = returned
        self.accepted = returned in (wx.wxID_OK, wx.wxID_YES)
        self.returnedString = returnedString(returned)

    def __repr__(self):
        return str(self.__dict__)

def returnedString(ret):
    if ret == wx.wxID_OK:
        return "Ok"
    elif ret == wx.wxID_CANCEL:
        return "Cancel"
    elif ret == wx.wxID_YES:
        return "Yes"
    elif ret == wx.wxID_NO:
        return "No"


# findDialog was created before wxPython got a Find/Replace dialog
# but it may be instructive as to how a function wrapper can
# be added for your own custom dialogs
# this dialog is always modal, while wxFindReplaceDialog is
# modeless and so doesn't lend itself to a function wrapper
def findDialog(parent=None, searchText='', wholeWordsOnly=0, caseSensitive=0):
    dlg = wx.wxDialog(parent, -1, "Find", wx.wxDefaultPosition, wx.wxSize(370, 120))

    wx.wxStaticText(dlg, -1, 'Find what:', wx.wxPoint(7, 10))
    wSearchText = wx.wxTextCtrl(dlg, -1, searchText,
                                wx.wxPoint(70, 7), wx.wxSize(195, -1))
    wSearchText.SetValue(searchText)
    wx.wxButton(dlg, wx.wxID_OK, "Find Next", wx.wxPoint(280, 5), wx.wxDefaultSize).SetDefault()
    wx.wxButton(dlg, wx.wxID_CANCEL, "Cancel", wx.wxPoint(280, 35), wx.wxDefaultSize)
    wWholeWord = wx.wxCheckBox(dlg, -1, 'Match whole word only',
                            wx.wxPoint(7, 35), wx.wxDefaultSize, wx.wxNO_BORDER)
    if wholeWordsOnly:
        wWholeWord.SetValue(1)
    wCase = wx.wxCheckBox(dlg, -1, 'Match case',
                        wx.wxPoint(7, 55), wx.wxDefaultSize, wx.wxNO_BORDER)
    if caseSensitive:
        wCase.SetValue(1)
    wSearchText.SetSelection(0, len(wSearchText.GetValue()))
    wSearchText.SetFocus()

    result = DialogResults(dlg.ShowModal())
    result.text = wSearchText.GetValue()
    result.wholeword = wWholeWord.GetValue()
    result.casesensitive = wCase.GetValue()
    dlg.Destroy()
    return result


def colorDialog(parent=None, colorData=None, color=None):
    if colorData:
        dialog = wx.wxColourDialog(parent, colorData)
    else:
        dialog = wx.wxColourDialog(parent)
        dialog.GetColourData().SetChooseFull(1)
    if color is not None:
        dialog.GetColourData().SetColour(color)
    result = DialogResults(dialog.ShowModal())
    result.colorData = dialog.GetColourData()
    result.color = result.colorData.GetColour().Get()
    dialog.Destroy()
    return result

# it is easier to just duplicate the code than
# try and replace color with colour in the result
def colourDialog(parent=None, colourData=None, colour=None):
    if colourData:
        dialog = wx.wxColourDialog(parent, colourData)
    else:
        dialog = wx.wxColourDialog(parent)
        dialog.GetColourData().SetChooseFull(1)
    if colour is not None:
        dialog.GetColourData().SetColour(color)
    result = DialogResults(dialog.ShowModal())
    result.colourData = dialog.GetColourData()
    result.colour = result.colourData.GetColour().Get()
    dialog.Destroy()
    return result


def fontDialog(parent=None, fontData=None, font=None):
    if fontData is None:
        fontData = wx.wxFontData()
    if font is not None:
        aFontData.SetInitialFont(font)
    dialog = wx.wxFontDialog(parent, fontData)
    result = DialogResults(dialog.ShowModal())
    if result.accepted:
        fontData = dialog.GetFontData()
        result.fontData = fontData
        result.color = fontData.GetColour().Get()
        result.colour = result.color
        result.font = fontData.GetChosenFont()
    else:
        result.color = None
        result.colour = None
        result.font = None
    dialog.Destroy()
    return result


def textEntryDialog(parent=None, message='', title='', defaultText='', style=wx.wxOK | wx.wxCANCEL):
    dialog = wx.wxTextEntryDialog(parent, message, title, defaultText, style)
    result = DialogResults(dialog.ShowModal())
    result.text = dialog.GetValue()
    dialog.Destroy()
    return result


def messageDialog(parent=None, message='', title='Message box',
                  aStyle = wx.wxOK | wx.wxCANCEL | wx.wxCENTRE,
                  pos=wx.wxDefaultPosition):
    dialog = wx.wxMessageDialog(parent, message, title, aStyle, pos)
    result = DialogResults(dialog.ShowModal())
    dialog.Destroy()
    return result


# KEA alerts are common, so I'm providing a class rather than
# requiring the user code to set up the right icons and buttons
# the with messageDialog function
def alertDialog(parent=None, message='', title='Alert', pos=wx.wxDefaultPosition):
    return messageDialog(parent, message, title, wx.wxICON_EXCLAMATION | wx.wxOK, pos)


def scrolledMessageDialog(parent=None, message='', title='', pos=wx.wxDefaultPosition, size=(500,300)):
    dialog = wxScrolledMessageDialog(parent, message, title, pos, size)
    result = DialogResults(dialog.ShowModal())
    dialog.Destroy()
    return result


def fileDialog(parent=None, title='Open', directory='', filename='', wildcard='*.*',
                style=wx.wxOPEN | wx.wxMULTIPLE):
    dialog = wx.wxFileDialog(parent, title, directory, filename, wildcard, style)
    result = DialogResults(dialog.ShowModal())
    if result.accepted:
        result.paths = dialog.GetPaths()
    else:
        result.paths = None
    dialog.Destroy()
    return result


# openFileDialog and saveFileDialog are convenience functions
# they represent the most common usages of the fileDialog
# with the most common style options
def openFileDialog(parent=None, title='Open', directory='', filename='',
                    wildcard='All Files (*.*)|*.*',
                    style=wx.wxOPEN | wx.wxMULTIPLE):
    return fileDialog(parent, title, directory, filename, wildcard, style)


def saveFileDialog(parent=None, title='Save', directory='', filename='',
                    wildcard='All Files (*.*)|*.*',
                    style=wx.wxSAVE | wx.wxHIDE_READONLY | wx.wxOVERWRITE_PROMPT):
    return fileDialog(parent, title, directory, filename, wildcard, style)


def dirDialog(parent=None, message='Choose a directory', path='', style=0,
                pos=wx.wxDefaultPosition, size=wx.wxDefaultSize):
    dialog = wx.wxDirDialog(parent, message, path, style, pos, size)
    result = DialogResults(dialog.ShowModal())
    if result.accepted:
        result.path = dialog.GetPath()
    else:
        result.path = None
    dialog.Destroy()
    return result

directoryDialog = dirDialog


def singleChoiceDialog(parent=None, message='', title='', lst=[],
                  style=wx.wxOK | wx.wxCANCEL | wx.wxCENTRE):
    dialog = wx.wxSingleChoiceDialog(parent,
                                    message,
                                    title,
                                    lst,
                                    style)
    result = DialogResults(dialog.ShowModal())
    result.selection = dialog.GetStringSelection()
    dialog.Destroy()
    return result


def multipleChoiceDialog(parent=None, message='', title='', lst=[], pos=wx.wxDefaultPosition, size=(200,200)):
    dialog = wxMultipleChoiceDialog(parent, message, title, lst, pos, size)
    result = DialogResults(dialog.ShowModal())
    result.selection = dialog.GetValueString()
    dialog.Destroy()
    return result


if __name__ == '__main__':
    class MyApp(wx.wxApp):

        def OnInit(self):
            frame = wx.wxFrame(wx.NULL, -1, "Dialogs", size=(400, 200))
            panel = wx.wxPanel(frame, -1)
            self.panel = panel

            frame.Show(1)

            dialogNames = [
                'alertDialog',
                'colorDialog',
                'directoryDialog',
                'fileDialog',
                'findDialog',
                'fontDialog',
                'messageDialog',
                'multipleChoiceDialog',
                'openFileDialog',
                'saveFileDialog',
                'scrolledMessageDialog',
                'singleChoiceDialog',
                'textEntryDialog',
            ]
            self.nameList = wx.wxListBox(panel, -1, (0, 0), (130, 180), dialogNames, style=wx.wxLB_SINGLE)
            wx.EVT_LISTBOX(panel, self.nameList.GetId(), self.OnNameListSelected)

            tstyle = wx.wxTE_RICH2 | wx.wxTE_PROCESS_TAB | wx.wxTE_MULTILINE
            self.text1 = wx.wxTextCtrl(panel, -1, pos=(150, 0), size=(200, 180), style=tstyle)

            self.SetTopWindow(frame)

            return 1

        def OnNameListSelected(self, evt):
            import pprint
            sel = evt.GetString()
            result = None
            if sel == 'alertDialog':
                result = alertDialog(message='Danger Will Robinson')
            elif sel == 'colorDialog':
                result = colorDialog()
            elif sel == 'directoryDialog':
                result = directoryDialog()
            elif sel == 'fileDialog':
                wildcard = "JPG files (*.jpg;*.jpeg)|*.jpeg;*.JPG;*.JPEG;*.jpg|GIF files (*.gif)|*.GIF;*.gif|All Files (*.*)|*.*"
                result = fileDialog(None, 'Open', '', '', wildcard)
            elif sel == 'findDialog':
                result = findDialog()
            elif sel == 'fontDialog':
                result = fontDialog()
            elif sel == 'messageDialog':
                result = messageDialog(None, 'Hello from Python and wxPython!',
                          'A Message Box', wx.wxOK | wx.wxICON_INFORMATION)
                          #wx.wxYES_NO | wx.wxNO_DEFAULT | wx.wxCANCEL | wx.wxICON_INFORMATION)
                #result = messageDialog(None, 'message', 'title')
            elif sel == 'multipleChoiceDialog':
                result = multipleChoiceDialog(None, "message", "title", ['one', 'two', 'three'])
            elif sel == 'openFileDialog':
                result = openFileDialog()
            elif sel == 'saveFileDialog':
                result = saveFileDialog()
            elif sel == 'scrolledMessageDialog':
                msg = "Can't find the file dialog.py"
                try:
                    # read this source file and then display it
                    import sys
                    filename = sys.argv[-1]
                    fp = open(filename)
                    message = fp.read()
                    fp.close()
                except:
                    pass
                result = scrolledMessageDialog(None, message, filename)
            elif sel == 'singleChoiceDialog':
                result = singleChoiceDialog(None, "message", "title", ['one', 'two', 'three'])
            elif sel == 'textEntryDialog':
                result = textEntryDialog(None, "message", "title", "text")

            if result:
                #self.text1.SetValue(pprint.pformat(result.__dict__))
                self.text1.SetValue(str(result))

    app = MyApp(0)
    app.MainLoop()



# This file was created automatically by SWIG.
import gdic

from misc import *

from fonts import *
import wx
class wxGDIObjectPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxGDIObject):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetVisible(self, *_args, **_kwargs):
        val = apply(gdic.wxGDIObject_GetVisible,(self,) + _args, _kwargs)
        return val
    def SetVisible(self, *_args, **_kwargs):
        val = apply(gdic.wxGDIObject_SetVisible,(self,) + _args, _kwargs)
        return val
    def IsNull(self, *_args, **_kwargs):
        val = apply(gdic.wxGDIObject_IsNull,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGDIObject instance at %s>" % (self.this,)
class wxGDIObject(wxGDIObjectPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxGDIObject,_args,_kwargs)
        self.thisown = 1




class wxBitmapPtr(wxGDIObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxBitmap):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetPalette(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_GetPalette,(self,) + _args, _kwargs)
        if val: val = wxPalettePtr(val) 
        return val
    def GetMask(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_GetMask,(self,) + _args, _kwargs)
        if val: val = wxMaskPtr(val) 
        return val
    def LoadFile(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_LoadFile,(self,) + _args, _kwargs)
        return val
    def SaveFile(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_SaveFile,(self,) + _args, _kwargs)
        return val
    def SetMask(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_SetMask,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_Ok,(self,) + _args, _kwargs)
        return val
    def GetWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_GetWidth,(self,) + _args, _kwargs)
        return val
    def GetHeight(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_GetHeight,(self,) + _args, _kwargs)
        return val
    def GetDepth(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_GetDepth,(self,) + _args, _kwargs)
        return val
    def SetWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_SetWidth,(self,) + _args, _kwargs)
        return val
    def SetHeight(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_SetHeight,(self,) + _args, _kwargs)
        return val
    def SetDepth(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_SetDepth,(self,) + _args, _kwargs)
        return val
    def GetSubBitmap(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_GetSubBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def CopyFromIcon(self, *_args, **_kwargs):
        val = apply(gdic.wxBitmap_CopyFromIcon,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxBitmap instance at %s>" % (self.this,)
    
    def SetMaskColour(self, colour):
        mask = wxMaskColour(self, colour)
        self.SetMask(mask)
    
class wxBitmap(wxBitmapPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxBitmap,_args,_kwargs)
        self.thisown = 1




class wxMaskPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Destroy(self, *_args, **_kwargs):
        val = apply(gdic.wxMask_Destroy,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMask instance at %s>" % (self.this,)
class wxMask(wxMaskPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxMask,_args,_kwargs)
        self.thisown = 1




class wxIconPtr(wxGDIObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxIcon):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def LoadFile(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_LoadFile,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_Ok,(self,) + _args, _kwargs)
        return val
    def GetWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_GetWidth,(self,) + _args, _kwargs)
        return val
    def GetHeight(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_GetHeight,(self,) + _args, _kwargs)
        return val
    def GetDepth(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_GetDepth,(self,) + _args, _kwargs)
        return val
    def SetWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_SetWidth,(self,) + _args, _kwargs)
        return val
    def SetHeight(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_SetHeight,(self,) + _args, _kwargs)
        return val
    def SetDepth(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_SetDepth,(self,) + _args, _kwargs)
        return val
    def CopyFromBitmap(self, *_args, **_kwargs):
        val = apply(gdic.wxIcon_CopyFromBitmap,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxIcon instance at %s>" % (self.this,)
class wxIcon(wxIconPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxIcon,_args,_kwargs)
        self.thisown = 1




class wxIconBundlePtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxIconBundle):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def AddIcon(self, *_args, **_kwargs):
        val = apply(gdic.wxIconBundle_AddIcon,(self,) + _args, _kwargs)
        return val
    def AddIconFromFile(self, *_args, **_kwargs):
        val = apply(gdic.wxIconBundle_AddIconFromFile,(self,) + _args, _kwargs)
        return val
    def GetIcon(self, *_args, **_kwargs):
        val = apply(gdic.wxIconBundle_GetIcon,(self,) + _args, _kwargs)
        if val: val = wxIconPtr(val) 
        return val
    def __repr__(self):
        return "<C wxIconBundle instance at %s>" % (self.this,)
class wxIconBundle(wxIconBundlePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxIconBundle,_args,_kwargs)
        self.thisown = 1



def wxIconBundleFromFile(*_args,**_kwargs):
    val = wxIconBundlePtr(apply(gdic.new_wxIconBundleFromFile,_args,_kwargs))
    val.thisown = 1
    return val

def wxIconBundleFromIcon(*_args,**_kwargs):
    val = wxIconBundlePtr(apply(gdic.new_wxIconBundleFromIcon,_args,_kwargs))
    val.thisown = 1
    return val


class wxCursorPtr(wxGDIObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxCursor):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxCursor_Ok,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxCursor instance at %s>" % (self.this,)
class wxCursor(wxCursorPtr):
    def __init__(self,this):
        self.this = this




class wxColourPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxColour):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Red(self, *_args, **_kwargs):
        val = apply(gdic.wxColour_Red,(self,) + _args, _kwargs)
        return val
    def Green(self, *_args, **_kwargs):
        val = apply(gdic.wxColour_Green,(self,) + _args, _kwargs)
        return val
    def Blue(self, *_args, **_kwargs):
        val = apply(gdic.wxColour_Blue,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxColour_Ok,(self,) + _args, _kwargs)
        return val
    def Set(self, *_args, **_kwargs):
        val = apply(gdic.wxColour_Set,(self,) + _args, _kwargs)
        return val
    def Get(self, *_args, **_kwargs):
        val = apply(gdic.wxColour_Get,(self,) + _args, _kwargs)
        return val
    def __eq__(self, *_args, **_kwargs):
        val = apply(gdic.wxColour___eq__,(self,) + _args, _kwargs)
        return val
    def __ne__(self, *_args, **_kwargs):
        val = apply(gdic.wxColour___ne__,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxColour instance at %s>" % (self.this,)
    asTuple = Get
    def __str__(self):                  return str(self.asTuple())
    def __repr__(self):                 return 'wxColour:' + str(self.asTuple())
    def __nonzero__(self):              return self.Ok()
    def __getinitargs__(self):          return ()
    def __getstate__(self):             return self.asTuple()
    def __setstate__(self, state):      self.Set(*state)

class wxColour(wxColourPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxColour,_args,_kwargs)
        self.thisown = 1




class wxColourDatabasePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def FindColour(self, *_args, **_kwargs):
        val = apply(gdic.wxColourDatabase_FindColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) 
        return val
    def FindName(self, *_args, **_kwargs):
        val = apply(gdic.wxColourDatabase_FindName,(self,) + _args, _kwargs)
        return val
    def Append(self, *_args, **_kwargs):
        val = apply(gdic.wxColourDatabase_Append,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxColourDatabase instance at %s>" % (self.this,)
class wxColourDatabase(wxColourDatabasePtr):
    def __init__(self,this):
        self.this = this




class wxPenPtr(wxGDIObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxPen):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetCap(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_GetCap,(self,) + _args, _kwargs)
        return val
    def GetColour(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_GetColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetJoin(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_GetJoin,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_GetStyle,(self,) + _args, _kwargs)
        return val
    def GetWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_GetWidth,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_Ok,(self,) + _args, _kwargs)
        return val
    def SetCap(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_SetCap,(self,) + _args, _kwargs)
        return val
    def SetColour(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_SetColour,(self,) + _args, _kwargs)
        return val
    def SetJoin(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_SetJoin,(self,) + _args, _kwargs)
        return val
    def SetStyle(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_SetStyle,(self,) + _args, _kwargs)
        return val
    def SetWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_SetWidth,(self,) + _args, _kwargs)
        return val
    def SetDashes(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_SetDashes,(self,) + _args, _kwargs)
        return val
    def GetDashes(self, *_args, **_kwargs):
        val = apply(gdic.wxPen_GetDashes,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPen instance at %s>" % (self.this,)
class wxPen(wxPenPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxPen,_args,_kwargs)
        self.thisown = 1




class wxPyPenPtr(wxPenPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxPyPen):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetDashes(self, *_args, **_kwargs):
        val = apply(gdic.wxPyPen_SetDashes,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyPen instance at %s>" % (self.this,)
class wxPyPen(wxPyPenPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxPyPen,_args,_kwargs)
        self.thisown = 1




class wxPenListPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def AddPen(self, *_args, **_kwargs):
        val = apply(gdic.wxPenList_AddPen,(self,) + _args, _kwargs)
        return val
    def FindOrCreatePen(self, *_args, **_kwargs):
        val = apply(gdic.wxPenList_FindOrCreatePen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) 
        return val
    def RemovePen(self, *_args, **_kwargs):
        val = apply(gdic.wxPenList_RemovePen,(self,) + _args, _kwargs)
        return val
    def GetCount(self, *_args, **_kwargs):
        val = apply(gdic.wxPenList_GetCount,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPenList instance at %s>" % (self.this,)
class wxPenList(wxPenListPtr):
    def __init__(self,this):
        self.this = this




class wxBrushPtr(wxGDIObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxBrush):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetColour(self, *_args, **_kwargs):
        val = apply(gdic.wxBrush_GetColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetStipple(self, *_args, **_kwargs):
        val = apply(gdic.wxBrush_GetStipple,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) 
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(gdic.wxBrush_GetStyle,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxBrush_Ok,(self,) + _args, _kwargs)
        return val
    def SetColour(self, *_args, **_kwargs):
        val = apply(gdic.wxBrush_SetColour,(self,) + _args, _kwargs)
        return val
    def SetStipple(self, *_args, **_kwargs):
        val = apply(gdic.wxBrush_SetStipple,(self,) + _args, _kwargs)
        return val
    def SetStyle(self, *_args, **_kwargs):
        val = apply(gdic.wxBrush_SetStyle,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxBrush instance at %s>" % (self.this,)
class wxBrush(wxBrushPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxBrush,_args,_kwargs)
        self.thisown = 1




class wxBrushListPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def AddBrush(self, *_args, **_kwargs):
        val = apply(gdic.wxBrushList_AddBrush,(self,) + _args, _kwargs)
        return val
    def FindOrCreateBrush(self, *_args, **_kwargs):
        val = apply(gdic.wxBrushList_FindOrCreateBrush,(self,) + _args, _kwargs)
        if val: val = wxBrushPtr(val) 
        return val
    def RemoveBrush(self, *_args, **_kwargs):
        val = apply(gdic.wxBrushList_RemoveBrush,(self,) + _args, _kwargs)
        return val
    def GetCount(self, *_args, **_kwargs):
        val = apply(gdic.wxBrushList_GetCount,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxBrushList instance at %s>" % (self.this,)
class wxBrushList(wxBrushListPtr):
    def __init__(self,this):
        self.this = this




class wxDCPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxDC):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def BeginDrawing(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_BeginDrawing,(self,) + _args, _kwargs)
        return val
    def Blit(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_Blit,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_Clear,(self,) + _args, _kwargs)
        return val
    def CrossHair(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_CrossHair,(self,) + _args, _kwargs)
        return val
    def DestroyClippingRegion(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DestroyClippingRegion,(self,) + _args, _kwargs)
        return val
    def DeviceToLogicalX(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DeviceToLogicalX,(self,) + _args, _kwargs)
        return val
    def DeviceToLogicalXRel(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DeviceToLogicalXRel,(self,) + _args, _kwargs)
        return val
    def DeviceToLogicalY(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DeviceToLogicalY,(self,) + _args, _kwargs)
        return val
    def DeviceToLogicalYRel(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DeviceToLogicalYRel,(self,) + _args, _kwargs)
        return val
    def DrawArc(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawArc,(self,) + _args, _kwargs)
        return val
    def DrawCircle(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawCircle,(self,) + _args, _kwargs)
        return val
    def DrawEllipse(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawEllipse,(self,) + _args, _kwargs)
        return val
    def DrawEllipticArc(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawEllipticArc,(self,) + _args, _kwargs)
        return val
    def DrawIcon(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawIcon,(self,) + _args, _kwargs)
        return val
    def DrawLabel(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawLabel,(self,) + _args, _kwargs)
        return val
    def DrawImageLabel(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawImageLabel,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def DrawLine(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawLine,(self,) + _args, _kwargs)
        return val
    def DrawLines(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawLines,(self,) + _args, _kwargs)
        return val
    def DrawPolygon(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawPolygon,(self,) + _args, _kwargs)
        return val
    def DrawPoint(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawPoint,(self,) + _args, _kwargs)
        return val
    def DrawRectangle(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawRectangle,(self,) + _args, _kwargs)
        return val
    def DrawRectangleRect(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawRectangleRect,(self,) + _args, _kwargs)
        return val
    def DrawRotatedText(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawRotatedText,(self,) + _args, _kwargs)
        return val
    def DrawRoundedRectangle(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawRoundedRectangle,(self,) + _args, _kwargs)
        return val
    def DrawSpline(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawSpline,(self,) + _args, _kwargs)
        return val
    def DrawText(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawText,(self,) + _args, _kwargs)
        return val
    def EndDoc(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_EndDoc,(self,) + _args, _kwargs)
        return val
    def EndDrawing(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_EndDrawing,(self,) + _args, _kwargs)
        return val
    def EndPage(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_EndPage,(self,) + _args, _kwargs)
        return val
    def FloodFill(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_FloodFill,(self,) + _args, _kwargs)
        return val
    def GetBackground(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetBackground,(self,) + _args, _kwargs)
        if val: val = wxBrushPtr(val) ; val.thisown = 1
        return val
    def GetBrush(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetBrush,(self,) + _args, _kwargs)
        if val: val = wxBrushPtr(val) ; val.thisown = 1
        return val
    def GetCharHeight(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetCharHeight,(self,) + _args, _kwargs)
        return val
    def GetCharWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetCharWidth,(self,) + _args, _kwargs)
        return val
    def GetClippingBox(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetClippingBox,(self,) + _args, _kwargs)
        return val
    def GetFont(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetLogicalFunction(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetLogicalFunction,(self,) + _args, _kwargs)
        return val
    def GetLogicalScale(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetLogicalScale,(self,) + _args, _kwargs)
        return val
    def GetMapMode(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetMapMode,(self,) + _args, _kwargs)
        return val
    def GetOptimization(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetOptimization,(self,) + _args, _kwargs)
        return val
    def GetPen(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetPen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) ; val.thisown = 1
        return val
    def GetPixel(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetPixel,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetSizeTuple(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetSizeTuple,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetSizeMM(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetSizeMM,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetTextBackground(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetTextBackground,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetTextExtent(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetTextExtent,(self,) + _args, _kwargs)
        return val
    def GetFullTextExtent(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetFullTextExtent,(self,) + _args, _kwargs)
        return val
    def GetMultiLineTextExtent(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetMultiLineTextExtent,(self,) + _args, _kwargs)
        return val
    def GetTextForeground(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetTextForeground,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetUserScale(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetUserScale,(self,) + _args, _kwargs)
        return val
    def LogicalToDeviceX(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_LogicalToDeviceX,(self,) + _args, _kwargs)
        return val
    def LogicalToDeviceXRel(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_LogicalToDeviceXRel,(self,) + _args, _kwargs)
        return val
    def LogicalToDeviceY(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_LogicalToDeviceY,(self,) + _args, _kwargs)
        return val
    def LogicalToDeviceYRel(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_LogicalToDeviceYRel,(self,) + _args, _kwargs)
        return val
    def MaxX(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_MaxX,(self,) + _args, _kwargs)
        return val
    def MaxY(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_MaxY,(self,) + _args, _kwargs)
        return val
    def MinX(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_MinX,(self,) + _args, _kwargs)
        return val
    def MinY(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_MinY,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_Ok,(self,) + _args, _kwargs)
        return val
    def SetDeviceOrigin(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetDeviceOrigin,(self,) + _args, _kwargs)
        return val
    def SetBackground(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetBackground,(self,) + _args, _kwargs)
        return val
    def SetBackgroundMode(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetBackgroundMode,(self,) + _args, _kwargs)
        return val
    def SetClippingRegion(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetClippingRegion,(self,) + _args, _kwargs)
        return val
    def SetClippingRegionAsRegion(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetClippingRegionAsRegion,(self,) + _args, _kwargs)
        return val
    def SetClippingRect(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetClippingRect,(self,) + _args, _kwargs)
        return val
    def SetPalette(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetPalette,(self,) + _args, _kwargs)
        return val
    def SetBrush(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetBrush,(self,) + _args, _kwargs)
        return val
    def SetFont(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetFont,(self,) + _args, _kwargs)
        return val
    def SetLogicalFunction(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetLogicalFunction,(self,) + _args, _kwargs)
        return val
    def SetLogicalScale(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetLogicalScale,(self,) + _args, _kwargs)
        return val
    def SetMapMode(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetMapMode,(self,) + _args, _kwargs)
        return val
    def SetOptimization(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetOptimization,(self,) + _args, _kwargs)
        return val
    def SetPen(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetPen,(self,) + _args, _kwargs)
        return val
    def SetTextBackground(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetTextBackground,(self,) + _args, _kwargs)
        return val
    def SetTextForeground(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetTextForeground,(self,) + _args, _kwargs)
        return val
    def SetUserScale(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetUserScale,(self,) + _args, _kwargs)
        return val
    def StartDoc(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_StartDoc,(self,) + _args, _kwargs)
        return val
    def StartPage(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_StartPage,(self,) + _args, _kwargs)
        return val
    def DrawBitmap(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_DrawBitmap,(self,) + _args, _kwargs)
        return val
    def CanDrawBitmap(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_CanDrawBitmap,(self,) + _args, _kwargs)
        return val
    def CanGetTextExtent(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_CanGetTextExtent,(self,) + _args, _kwargs)
        return val
    def GetDepth(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetDepth,(self,) + _args, _kwargs)
        return val
    def GetPPI(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetPPI,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetLogicalOrigin(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetLogicalOrigin,(self,) + _args, _kwargs)
        return val
    def SetLogicalOrigin(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetLogicalOrigin,(self,) + _args, _kwargs)
        return val
    def GetDeviceOrigin(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetDeviceOrigin,(self,) + _args, _kwargs)
        return val
    def SetAxisOrientation(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_SetAxisOrientation,(self,) + _args, _kwargs)
        return val
    def CalcBoundingBox(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_CalcBoundingBox,(self,) + _args, _kwargs)
        return val
    def ResetBoundingBox(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_ResetBoundingBox,(self,) + _args, _kwargs)
        return val
    def GetBoundingBox(self, *_args, **_kwargs):
        val = apply(gdic.wxDC_GetBoundingBox,(self,) + _args, _kwargs)
        return val
    def _DrawPointList(self, *_args, **_kwargs):
        val = apply(gdic.wxDC__DrawPointList,(self,) + _args, _kwargs)
        return val
    def _DrawLineList(self, *_args, **_kwargs):
        val = apply(gdic.wxDC__DrawLineList,(self,) + _args, _kwargs)
        return val
    def _DrawRectangleList(self, *_args, **_kwargs):
        val = apply(gdic.wxDC__DrawRectangleList,(self,) + _args, _kwargs)
        return val
    def _DrawEllipseList(self, *_args, **_kwargs):
        val = apply(gdic.wxDC__DrawEllipseList,(self,) + _args, _kwargs)
        return val
    def _DrawPolygonList(self, *_args, **_kwargs):
        val = apply(gdic.wxDC__DrawPolygonList,(self,) + _args, _kwargs)
        return val
    def _DrawTextList(self, *_args, **_kwargs):
        val = apply(gdic.wxDC__DrawTextList,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDC instance at %s>" % (self.this,)
    
    def DrawPointList(self, points, pens=None):
        if pens is None:
           pens = []
        elif isinstance(pens, wxPenPtr):
           pens = [pens]
        elif len(pens) != len(points):
           raise ValueError('points and pens must have same length')
        return self._DrawPointList(points, pens, [])


    def DrawLineList(self, lines, pens=None):
        if pens is None:
           pens = []
        elif isinstance(pens, wxPenPtr):
           pens = [pens]
        elif len(pens) != len(lines):
           raise ValueError('lines and pens must have same length')
        return self._DrawLineList(lines, pens, [])


    def DrawRectangleList(self, rectangles, pens=None, brushes=None):
        if pens is None:
           pens = []
        elif isinstance(pens, wxPenPtr):
           pens = [pens]
        elif len(pens) != len(rectangles):
           raise ValueError('rectangles and pens must have same length')
        if brushes is None:
           brushes = []
        elif isinstance(brushes, wxBrushPtr):
           brushes = [brushes]
        elif len(brushes) != len(rectangles):
           raise ValueError('rectangles and brushes must have same length')
        return self._DrawRectangleList(rectangles, pens, brushes)


    def DrawEllipseList(self, ellipses, pens=None, brushes=None):
        if pens is None:
           pens = []
        elif isinstance(pens, wxPenPtr):
           pens = [pens]
        elif len(pens) != len(ellipses):
           raise ValueError('ellipses and pens must have same length')
        if brushes is None:
           brushes = []
        elif isinstance(brushes, wxBrushPtr):
           brushes = [brushes]
        elif len(brushes) != len(ellipses):
           raise ValueError('ellipses and brushes must have same length')
        return self._DrawEllipseList(ellipses, pens, brushes)


    def DrawPolygonList(self, polygons, pens=None, brushes=None):
        ## Note: This does not currently support fill style or offset
        ## you can always use the non-List version if need be.
        ## I really would like to support fill-style, however,
        ## but wxODDEVEN_RULE does not appear to be defined at the Python level
        ## [It's in wx.py... --Robin]
        if pens is None:
           pens = []
        elif isinstance(pens, wxPenPtr):
           pens = [pens]
        elif len(pens) != len(polygons):
           raise ValueError('polygons and pens must have same length')
        if brushes is None:
           brushes = []
        elif isinstance(brushes, wxBrushPtr):
           brushes = [brushes]
        elif len(brushes) != len(polygons):
           raise ValueError('polygons and brushes must have same length')
        return self._DrawPolygonList(polygons, pens, brushes)


    def DrawTextList(self, textList, coords, foregrounds = None, backgrounds = None, fonts = None):
        ## NOTE: this does not currently support changing the font
        ##       Make sure you set Background mode to wxSolid (DC.SetBackgroundMode)
        ##       If you want backgounds to do anything.
        if type(textList) == type(''):
           textList = [textList]
        elif len(textList) != len(coords):
           raise ValueError('textlist and coords must have same length')
        if foregrounds is None:
           foregrounds = []
        elif isinstance(foregrounds, wxColourPtr):
           foregrounds = [foregrounds]
        elif len(foregrounds) != len(coords):
           raise ValueError('foregrounds and coords must have same length')
        if backgrounds is None:
           backgrounds = []
        elif isinstance(backgrounds, wxColourPtr):
           backgrounds = [backgrounds]
        elif len(backgrounds) != len(coords):
           raise ValueError('backgrounds and coords must have same length')
        return  self._DrawTextList(textList, coords, foregrounds, backgrounds)

class wxDC(wxDCPtr):
    def __init__(self,this):
        self.this = this




class wxMemoryDCPtr(wxDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SelectObject(self, *_args, **_kwargs):
        val = apply(gdic.wxMemoryDC_SelectObject,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMemoryDC instance at %s>" % (self.this,)
class wxMemoryDC(wxMemoryDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxMemoryDC,_args,_kwargs)
        self.thisown = 1




class wxBufferedDCPtr(wxMemoryDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def UnMask(self, *_args, **_kwargs):
        val = apply(gdic.wxBufferedDC_UnMask,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxBufferedDC instance at %s>" % (self.this,)
class wxBufferedDC(wxBufferedDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxBufferedDC,_args,_kwargs)
        self.thisown = 1
        self._dc = _args[0] # save a ref so the other dc won't be deleted before self



def wxBufferedDCInternalBuffer(*_args,**_kwargs):
    val = wxBufferedDCPtr(apply(gdic.new_wxBufferedDCInternalBuffer,_args,_kwargs))
    val.thisown = 1
    val._dc = _args[0] # save a ref so the other dc won't be deleted before self
    return val


class wxBufferedPaintDCPtr(wxBufferedDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxBufferedPaintDC instance at %s>" % (self.this,)
class wxBufferedPaintDC(wxBufferedPaintDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxBufferedPaintDC,_args,_kwargs)
        self.thisown = 1




class wxScreenDCPtr(wxDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def StartDrawingOnTopWin(self, *_args, **_kwargs):
        val = apply(gdic.wxScreenDC_StartDrawingOnTopWin,(self,) + _args, _kwargs)
        return val
    def StartDrawingOnTop(self, *_args, **_kwargs):
        val = apply(gdic.wxScreenDC_StartDrawingOnTop,(self,) + _args, _kwargs)
        return val
    def EndDrawingOnTop(self, *_args, **_kwargs):
        val = apply(gdic.wxScreenDC_EndDrawingOnTop,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxScreenDC instance at %s>" % (self.this,)
class wxScreenDC(wxScreenDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxScreenDC,_args,_kwargs)
        self.thisown = 1




class wxClientDCPtr(wxDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxClientDC instance at %s>" % (self.this,)
class wxClientDC(wxClientDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxClientDC,_args,_kwargs)
        self.thisown = 1




class wxPaintDCPtr(wxDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxPaintDC instance at %s>" % (self.this,)
class wxPaintDC(wxPaintDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxPaintDC,_args,_kwargs)
        self.thisown = 1




class wxWindowDCPtr(wxDCPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxWindowDC instance at %s>" % (self.this,)
class wxWindowDC(wxWindowDCPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxWindowDC,_args,_kwargs)
        self.thisown = 1




class wxPalettePtr(wxGDIObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxPalette):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetPixel(self, *_args, **_kwargs):
        val = apply(gdic.wxPalette_GetPixel,(self,) + _args, _kwargs)
        return val
    def GetRGB(self, *_args, **_kwargs):
        val = apply(gdic.wxPalette_GetRGB,(self,) + _args, _kwargs)
        return val
    def Ok(self, *_args, **_kwargs):
        val = apply(gdic.wxPalette_Ok,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPalette instance at %s>" % (self.this,)
class wxPalette(wxPalettePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxPalette,_args,_kwargs)
        self.thisown = 1




class wxImageListPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxImageList):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Add(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_Add,(self,) + _args, _kwargs)
        return val
    def AddWithColourMask(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_AddWithColourMask,(self,) + _args, _kwargs)
        return val
    def AddIcon(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_AddIcon,(self,) + _args, _kwargs)
        return val
    def Replace(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_Replace,(self,) + _args, _kwargs)
        return val
    def Draw(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_Draw,(self,) + _args, _kwargs)
        return val
    def GetImageCount(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_GetImageCount,(self,) + _args, _kwargs)
        return val
    def Remove(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_Remove,(self,) + _args, _kwargs)
        return val
    def RemoveAll(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_RemoveAll,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(gdic.wxImageList_GetSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxImageList instance at %s>" % (self.this,)
class wxImageList(wxImageListPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxImageList,_args,_kwargs)
        self.thisown = 1




class wxRegionPtr(wxGDIObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxRegion):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def Clear(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_Clear,(self,) + _args, _kwargs)
        return val
    def Offset(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_Offset,(self,) + _args, _kwargs)
        return val
    def Contains(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_Contains,(self,) + _args, _kwargs)
        return val
    def ContainsPoint(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_ContainsPoint,(self,) + _args, _kwargs)
        return val
    def ContainsRect(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_ContainsRect,(self,) + _args, _kwargs)
        return val
    def ContainsRectDim(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_ContainsRectDim,(self,) + _args, _kwargs)
        return val
    def GetBox(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_GetBox,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def Intersect(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_Intersect,(self,) + _args, _kwargs)
        return val
    def IntersectRect(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_IntersectRect,(self,) + _args, _kwargs)
        return val
    def IntersectRegion(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_IntersectRegion,(self,) + _args, _kwargs)
        return val
    def IsEmpty(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_IsEmpty,(self,) + _args, _kwargs)
        return val
    def Union(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_Union,(self,) + _args, _kwargs)
        return val
    def UnionRect(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_UnionRect,(self,) + _args, _kwargs)
        return val
    def UnionRegion(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_UnionRegion,(self,) + _args, _kwargs)
        return val
    def Subtract(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_Subtract,(self,) + _args, _kwargs)
        return val
    def SubtractRect(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_SubtractRect,(self,) + _args, _kwargs)
        return val
    def SubtractRegion(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_SubtractRegion,(self,) + _args, _kwargs)
        return val
    def Xor(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_Xor,(self,) + _args, _kwargs)
        return val
    def XorRect(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_XorRect,(self,) + _args, _kwargs)
        return val
    def XorRegion(self, *_args, **_kwargs):
        val = apply(gdic.wxRegion_XorRegion,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxRegion instance at %s>" % (self.this,)
class wxRegion(wxRegionPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxRegion,_args,_kwargs)
        self.thisown = 1



def wxRegionFromPoints(*_args,**_kwargs):
    val = wxRegionPtr(apply(gdic.new_wxRegionFromPoints,_args,_kwargs))
    val.thisown = 1
    return val


class wxRegionIteratorPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gdic.delete_wxRegionIterator):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetX(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_GetX,(self,) + _args, _kwargs)
        return val
    def GetY(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_GetY,(self,) + _args, _kwargs)
        return val
    def GetW(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_GetW,(self,) + _args, _kwargs)
        return val
    def GetWidth(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_GetWidth,(self,) + _args, _kwargs)
        return val
    def GetH(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_GetH,(self,) + _args, _kwargs)
        return val
    def GetHeight(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_GetHeight,(self,) + _args, _kwargs)
        return val
    def GetRect(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_GetRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def HaveRects(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_HaveRects,(self,) + _args, _kwargs)
        return val
    def Reset(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_Reset,(self,) + _args, _kwargs)
        return val
    def Next(self, *_args, **_kwargs):
        val = apply(gdic.wxRegionIterator_Next,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxRegionIterator instance at %s>" % (self.this,)
class wxRegionIterator(wxRegionIteratorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gdic.new_wxRegionIterator,_args,_kwargs)
        self.thisown = 1






#-------------- FUNCTION WRAPPERS ------------------

def wxEmptyBitmap(*_args, **_kwargs):
    val = apply(gdic.wxEmptyBitmap,_args,_kwargs)
    if val: val = wxBitmapPtr(val); val.thisown = 1
    return val

def wxBitmapFromXPMData(*_args, **_kwargs):
    val = apply(gdic.wxBitmapFromXPMData,_args,_kwargs)
    if val: val = wxBitmapPtr(val); val.thisown = 1
    return val

def wxBitmapFromIcon(*_args, **_kwargs):
    val = apply(gdic.wxBitmapFromIcon,_args,_kwargs)
    if val: val = wxBitmapPtr(val); val.thisown = 1
    return val

def wxBitmapFromBits(*_args, **_kwargs):
    val = apply(gdic.wxBitmapFromBits,_args,_kwargs)
    if val: val = wxBitmapPtr(val); val.thisown = 1
    return val

def wxMaskColour(*_args, **_kwargs):
    val = apply(gdic.wxMaskColour,_args,_kwargs)
    if val: val = wxMaskPtr(val); val.thisown = 1
    return val

def wxEmptyIcon(*_args, **_kwargs):
    val = apply(gdic.wxEmptyIcon,_args,_kwargs)
    if val: val = wxIconPtr(val); val.thisown = 1
    return val

def wxIconFromXPMData(*_args, **_kwargs):
    val = apply(gdic.wxIconFromXPMData,_args,_kwargs)
    if val: val = wxIconPtr(val); val.thisown = 1
    return val

def wxIconFromBitmap(*_args, **_kwargs):
    val = apply(gdic.wxIconFromBitmap,_args,_kwargs)
    if val: val = wxIconPtr(val); val.thisown = 1
    return val

def wxStockCursor(*_args, **_kwargs):
    val = apply(gdic.wxStockCursor,_args,_kwargs)
    if val: val = wxCursorPtr(val); val.thisown = 1
    return val

def wxCursorFromImage(*_args, **_kwargs):
    val = apply(gdic.wxCursorFromImage,_args,_kwargs)
    if val: val = wxCursorPtr(val); val.thisown = 1
    return val

def wxNamedColour(*_args, **_kwargs):
    val = apply(gdic.wxNamedColour,_args,_kwargs)
    if val: val = wxColourPtr(val); val.thisown = 1
    return val

def wxMemoryDCFromDC(*_args, **_kwargs):
    val = apply(gdic.wxMemoryDCFromDC,_args,_kwargs)
    if val: val = wxMemoryDCPtr(val); val.thisown = 1
    return val



#-------------- VARIABLE WRAPPERS ------------------

wxIMAGELIST_DRAW_NORMAL = gdic.wxIMAGELIST_DRAW_NORMAL
wxIMAGELIST_DRAW_TRANSPARENT = gdic.wxIMAGELIST_DRAW_TRANSPARENT
wxIMAGELIST_DRAW_SELECTED = gdic.wxIMAGELIST_DRAW_SELECTED
wxIMAGELIST_DRAW_FOCUSED = gdic.wxIMAGELIST_DRAW_FOCUSED
wxIMAGE_LIST_NORMAL = gdic.wxIMAGE_LIST_NORMAL
wxIMAGE_LIST_SMALL = gdic.wxIMAGE_LIST_SMALL
wxIMAGE_LIST_STATE = gdic.wxIMAGE_LIST_STATE
wxOutRegion = gdic.wxOutRegion
wxPartRegion = gdic.wxPartRegion
wxInRegion = gdic.wxInRegion
cvar = gdic.cvar
wxNORMAL_FONT = wxFontPtr(gdic.cvar.wxNORMAL_FONT)
wxSMALL_FONT = wxFontPtr(gdic.cvar.wxSMALL_FONT)
wxITALIC_FONT = wxFontPtr(gdic.cvar.wxITALIC_FONT)
wxSWISS_FONT = wxFontPtr(gdic.cvar.wxSWISS_FONT)
wxRED_PEN = wxPenPtr(gdic.cvar.wxRED_PEN)
wxCYAN_PEN = wxPenPtr(gdic.cvar.wxCYAN_PEN)
wxGREEN_PEN = wxPenPtr(gdic.cvar.wxGREEN_PEN)
wxBLACK_PEN = wxPenPtr(gdic.cvar.wxBLACK_PEN)
wxWHITE_PEN = wxPenPtr(gdic.cvar.wxWHITE_PEN)
wxTRANSPARENT_PEN = wxPenPtr(gdic.cvar.wxTRANSPARENT_PEN)
wxBLACK_DASHED_PEN = wxPenPtr(gdic.cvar.wxBLACK_DASHED_PEN)
wxGREY_PEN = wxPenPtr(gdic.cvar.wxGREY_PEN)
wxMEDIUM_GREY_PEN = wxPenPtr(gdic.cvar.wxMEDIUM_GREY_PEN)
wxLIGHT_GREY_PEN = wxPenPtr(gdic.cvar.wxLIGHT_GREY_PEN)
wxBLUE_BRUSH = wxBrushPtr(gdic.cvar.wxBLUE_BRUSH)
wxGREEN_BRUSH = wxBrushPtr(gdic.cvar.wxGREEN_BRUSH)
wxWHITE_BRUSH = wxBrushPtr(gdic.cvar.wxWHITE_BRUSH)
wxBLACK_BRUSH = wxBrushPtr(gdic.cvar.wxBLACK_BRUSH)
wxTRANSPARENT_BRUSH = wxBrushPtr(gdic.cvar.wxTRANSPARENT_BRUSH)
wxCYAN_BRUSH = wxBrushPtr(gdic.cvar.wxCYAN_BRUSH)
wxRED_BRUSH = wxBrushPtr(gdic.cvar.wxRED_BRUSH)
wxGREY_BRUSH = wxBrushPtr(gdic.cvar.wxGREY_BRUSH)
wxMEDIUM_GREY_BRUSH = wxBrushPtr(gdic.cvar.wxMEDIUM_GREY_BRUSH)
wxLIGHT_GREY_BRUSH = wxBrushPtr(gdic.cvar.wxLIGHT_GREY_BRUSH)
wxBLACK = wxColourPtr(gdic.cvar.wxBLACK)
wxWHITE = wxColourPtr(gdic.cvar.wxWHITE)
wxRED = wxColourPtr(gdic.cvar.wxRED)
wxBLUE = wxColourPtr(gdic.cvar.wxBLUE)
wxGREEN = wxColourPtr(gdic.cvar.wxGREEN)
wxCYAN = wxColourPtr(gdic.cvar.wxCYAN)
wxLIGHT_GREY = wxColourPtr(gdic.cvar.wxLIGHT_GREY)
wxSTANDARD_CURSOR = wxCursorPtr(gdic.cvar.wxSTANDARD_CURSOR)
wxHOURGLASS_CURSOR = wxCursorPtr(gdic.cvar.wxHOURGLASS_CURSOR)
wxCROSS_CURSOR = wxCursorPtr(gdic.cvar.wxCROSS_CURSOR)
wxNullBitmap = wxBitmapPtr(gdic.cvar.wxNullBitmap)
wxNullIcon = wxIconPtr(gdic.cvar.wxNullIcon)
wxNullCursor = wxCursorPtr(gdic.cvar.wxNullCursor)
wxNullPen = wxPenPtr(gdic.cvar.wxNullPen)
wxNullBrush = wxBrushPtr(gdic.cvar.wxNullBrush)
wxNullPalette = wxPalettePtr(gdic.cvar.wxNullPalette)
wxNullFont = wxFontPtr(gdic.cvar.wxNullFont)
wxNullColour = wxColourPtr(gdic.cvar.wxNullColour)
wxTheFontList = wxFontListPtr(gdic.cvar.wxTheFontList)
wxThePenList = wxPenListPtr(gdic.cvar.wxThePenList)
wxTheBrushList = wxBrushListPtr(gdic.cvar.wxTheBrushList)
wxTheColourDatabase = wxColourDatabasePtr(gdic.cvar.wxTheColourDatabase)



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Misc.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
import Parameters as wx


class ArtProvider(Object):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class BusyCursor:
    """"""

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class BusyInfo(Object):
    """"""

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class Caret:
    """"""

    def GetPosition(self):
        """"""
        pass

    def GetPositionTuple(self):
        """"""
        pass

    def GetSize(self):
        """"""
        pass

    def GetSizeTuple(self):
        """"""
        pass

    def GetWindow(self):
        """"""
        pass

    def Hide(self):
        """"""
        pass

    def IsOk(self):
        """"""
        pass

    def IsVisible(self):
        """"""
        pass

    def Move(self):
        """"""
        pass

    def MoveXY(self):
        """"""
        pass

    def SetSize(self):
        """"""
        pass

    def SetSizeWH(self):
        """"""
        pass

    def Show(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class EncodingConverter(Object):
    """"""

    def Convert(self):
        """"""
        pass

    def Init(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DirItemData(Object):
    """"""

    def SetNewDirName(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass


class Effects(Object):
    """"""

    def DrawSunkenEdge(self):
        """"""
        pass

    def GetDarkShadow(self):
        """"""
        pass

    def GetFaceColour(self):
        """"""
        pass

    def GetHighlightColour(self):
        """"""
        pass

    def GetLightShadow(self):
        """"""
        pass

    def GetMediumShadow(self):
        """"""
        pass

    def Set(self):
        """"""
        pass

    def SetDarkShadow(self):
        """"""
        pass

    def SetFaceColour(self):
        """"""
        pass

    def SetHighlightColour(self):
        """"""
        pass

    def SetLightShadow(self):
        """"""
        pass

    def SetMediumShadow(self):
        """"""
        pass

    def TileBitmap(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FontEnumerator:
    """"""

    def EnumerateEncodings(self):
        """"""
        pass

    def EnumerateFacenames(self):
        """"""
        pass

    def GetEncodings(self):
        """"""
        pass

    def GetFacenames(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass


class FontMapper:
    """"""

    def CharsetToEncoding(self):
        """"""
        pass

    def GetAltForEncoding(self):
        """"""
        pass

    def IsEncodingAvailable(self):
        """"""
        pass

    def SetConfig(self):
        """"""
        pass

    def SetConfigPath(self):
        """"""
        pass

    def SetDialogParent(self):
        """"""
        pass

    def SetDialogTitle(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class LanguageInfo:
    """"""

    def __getattr__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass


class Locale:
    """"""

    def AddCatalog(self):
        """"""
        pass

    def GetCanonicalName(self):
        """"""
        pass

    def GetLanguage(self):
        """"""
        pass

    def GetLocale(self):
        """"""
        pass

    def GetName(self):
        """"""
        pass

    def GetString(self):
        """"""
        pass

    def GetSysName(self):
        """"""
        pass

    def Init(self):
        """"""
        pass

    def IsLoaded(self):
        """"""
        pass

    def IsOk(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class NativeFontInfo:
    """"""

    def FromString(self):
        """"""
        pass

    def FromUserString(self):
        """"""
        pass

    def GetEncoding(self):
        """"""
        pass

    def GetFaceName(self):
        """"""
        pass

    def GetFamily(self):
        """"""
        pass

    def GetPointSize(self):
        """"""
        pass

    def GetStyle(self):
        """"""
        pass

    def GetUnderlined(self):
        """"""
        pass

    def GetWeight(self):
        """"""
        pass

    def Init(self):
        """"""
        pass

    def SetEncoding(self):
        """"""
        pass

    def SetFaceName(self):
        """"""
        pass

    def SetFamily(self):
        """"""
        pass

    def SetPointSize(self):
        """"""
        pass

    def SetStyle(self):
        """"""
        pass

    def SetUnderlined(self):
        """"""
        pass

    def SetWeight(self):
        """"""
        pass

    def ToString(self):
        """"""
        pass

    def ToUserString(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __str__(self):
        """"""
        pass


class PyTimer(Object):
    """"""

    def GetInterval(self):
        """"""
        pass

    def IsOneShot(self):
        """"""
        pass

    def IsRunning(self):
        """"""
        pass

    def SetOwner(self):
        """"""
        pass

    def Start(self):
        """"""
        pass

    def Stop(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class StopWatch:
    """"""

    def Pause(self):
        """"""
        pass

    def Resume(self):
        """"""
        pass

    def Start(self):
        """"""
        pass

    def Time(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SystemSettings:
    """"""

    def __init__(self):
        """"""
        pass


class Timer(PyTimer):
    """"""

    def __init__(self, evtHandler=None, id=-1):
        """Create a Timer instance."""
        pass


class Wave(Object):
    """"""

    def IsOk(self):
        """"""
        pass

    def Play(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class WindowDisabler:
    """"""

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


